# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-trading-helper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import mrpc_mt5_error_pb2 as mrpc__mt5__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!mt5-term-api-trading-helper.proto\x12\x0cmt5_term_api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14mrpc-mt5-error.proto\"E\n\x11OrderCloseRequest\x12\x0e\n\x06ticket\x18\x01 \x01(\x04\x12\x0e\n\x06volume\x18\x02 \x01(\x01\x12\x10\n\x08slippage\x18\x05 \x01(\x05\"q\n\x0fOrderCloseReply\x12,\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.mt5_term_api.OrderCloseDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xa1\x01\n\x0eOrderCloseData\x12\x15\n\rreturned_code\x18\x01 \x01(\r\x12\x1c\n\x14returned_string_code\x18\x02 \x01(\t\x12!\n\x19returned_code_description\x18\x03 \x01(\t\x12\x37\n\nclose_mode\x18\x04 \x01(\x0e\x32#.mt5_term_api.MRPC_ORDER_CLOSE_MODE\"\xed\x02\n\x12OrderModifyRequest\x12\x0e\n\x06ticket\x18\x01 \x01(\x04\x12\x16\n\tstop_loss\x18\x02 \x01(\x01H\x00\x88\x01\x01\x12\x18\n\x0btake_profit\x18\x03 \x01(\x01H\x01\x88\x01\x01\x12\x12\n\x05price\x18\x04 \x01(\x01H\x02\x88\x01\x01\x12J\n\x14\x65xpiration_time_type\x18\x05 \x01(\x0e\x32\'.mt5_term_api.TMT5_ENUM_ORDER_TYPE_TIMEH\x03\x88\x01\x01\x12\x38\n\x0f\x65xpiration_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04\x88\x01\x01\x12\x17\n\nstop_limit\x18\x08 \x01(\x01H\x05\x88\x01\x01\x42\x0c\n\n_stop_lossB\x0e\n\x0c_take_profitB\x08\n\x06_priceB\x17\n\x15_expiration_time_typeB\x12\n\x10_expiration_timeB\r\n\x0b_stop_limit\"s\n\x10OrderModifyReply\x12-\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1d.mt5_term_api.OrderModifyDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xff\x01\n\x0fOrderModifyData\x12\x15\n\rreturned_code\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x65\x61l\x18\x02 \x01(\x04\x12\r\n\x05order\x18\x03 \x01(\x04\x12\x0e\n\x06volume\x18\x04 \x01(\x01\x12\r\n\x05price\x18\x05 \x01(\x01\x12\x0b\n\x03\x62id\x18\x06 \x01(\x01\x12\x0b\n\x03\x61sk\x18\x07 \x01(\x01\x12\x0f\n\x07\x63omment\x18\x08 \x01(\t\x12\x12\n\nrequest_id\x18\t \x01(\r\x12\x19\n\x11ret_code_external\x18\n \x01(\x05\x12\x1c\n\x14returned_string_code\x18\x0b \x01(\t\x12!\n\x19returned_code_description\x18\x0c \x01(\t\"\xaa\x04\n\x10OrderSendRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x35\n\toperation\x18\x02 \x01(\x0e\x32\".mt5_term_api.TMT5_ENUM_ORDER_TYPE\x12\x0e\n\x06volume\x18\x03 \x01(\x01\x12\x12\n\x05price\x18\x04 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08slippage\x18\x05 \x01(\x04H\x01\x88\x01\x01\x12\x16\n\tstop_loss\x18\x06 \x01(\x01H\x02\x88\x01\x01\x12\x18\n\x0btake_profit\x18\x07 \x01(\x01H\x03\x88\x01\x01\x12\x14\n\x07\x63omment\x18\x08 \x01(\tH\x04\x88\x01\x01\x12\x16\n\texpert_id\x18\t \x01(\x04H\x05\x88\x01\x01\x12\x1d\n\x10stop_limit_price\x18\n \x01(\x01H\x06\x88\x01\x01\x12J\n\x14\x65xpiration_time_type\x18\x0b \x01(\x0e\x32\'.mt5_term_api.TMT5_ENUM_ORDER_TYPE_TIMEH\x07\x88\x01\x01\x12\x38\n\x0f\x65xpiration_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x42\x08\n\x06_priceB\x0b\n\t_slippageB\x0c\n\n_stop_lossB\x0e\n\x0c_take_profitB\n\n\x08_commentB\x0c\n\n_expert_idB\x13\n\x11_stop_limit_priceB\x17\n\x15_expiration_time_typeB\x12\n\x10_expiration_time\"o\n\x0eOrderSendReply\x12+\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1b.mt5_term_api.OrderSendDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xfd\x01\n\rOrderSendData\x12\x15\n\rreturned_code\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x65\x61l\x18\x02 \x01(\x04\x12\r\n\x05order\x18\x03 \x01(\x04\x12\x0e\n\x06volume\x18\x04 \x01(\x01\x12\r\n\x05price\x18\x05 \x01(\x01\x12\x0b\n\x03\x62id\x18\x06 \x01(\x01\x12\x0b\n\x03\x61sk\x18\x07 \x01(\x01\x12\x0f\n\x07\x63omment\x18\x08 \x01(\t\x12\x12\n\nrequest_id\x18\t \x01(\r\x12\x19\n\x11ret_code_external\x18\n \x01(\x05\x12\x1c\n\x14returned_string_code\x18\x0b \x01(\t\x12!\n\x19returned_code_description\x18\x0c \x01(\t*x\n\x15MRPC_ORDER_CLOSE_MODE\x12\x1b\n\x17MRPC_MARKET_ORDER_CLOSE\x10\x00\x12#\n\x1fMRPC_MARKET_ORDER_PARTIAL_CLOSE\x10\x01\x12\x1d\n\x19MRPC_PENDING_ORDER_REMOVE\x10\x02*\xac\x02\n\x14TMT5_ENUM_ORDER_TYPE\x12\x17\n\x13TMT5_ORDER_TYPE_BUY\x10\x00\x12\x18\n\x14TMT5_ORDER_TYPE_SELL\x10\x01\x12\x1d\n\x19TMT5_ORDER_TYPE_BUY_LIMIT\x10\x02\x12\x1e\n\x1aTMT5_ORDER_TYPE_SELL_LIMIT\x10\x03\x12\x1c\n\x18TMT5_ORDER_TYPE_BUY_STOP\x10\x04\x12\x1d\n\x19TMT5_ORDER_TYPE_SELL_STOP\x10\x05\x12\"\n\x1eTMT5_ORDER_TYPE_BUY_STOP_LIMIT\x10\x06\x12#\n\x1fTMT5_ORDER_TYPE_SELL_STOP_LIMIT\x10\x07\x12\x1c\n\x18TMT5_ORDER_TYPE_CLOSE_BY\x10\x08*\x8f\x01\n\x19TMT5_ENUM_ORDER_TYPE_TIME\x12\x17\n\x13TMT5_ORDER_TIME_GTC\x10\x00\x12\x17\n\x13TMT5_ORDER_TIME_DAY\x10\x01\x12\x1d\n\x19TMT5_ORDER_TIME_SPECIFIED\x10\x02\x12!\n\x1dTMT5_ORDER_TIME_SPECIFIED_DAY\x10\x03\x32\xb8\x02\n\rTradingHelper\x12]\n\tOrderSend\x12\x1e.mt5_term_api.OrderSendRequest\x1a\x1c.mt5_term_api.OrderSendReply\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/OrderSend\x12\x65\n\x0bOrderModify\x12 .mt5_term_api.OrderModifyRequest\x1a\x1e.mt5_term_api.OrderModifyReply\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/OrderModify\x12\x61\n\nOrderClose\x12\x1f.mt5_term_api.OrderCloseRequest\x1a\x1d.mt5_term_api.OrderCloseReply\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/OrderCloseBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_trading_helper_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _TRADINGHELPER.methods_by_name['OrderSend']._options = None
  _TRADINGHELPER.methods_by_name['OrderSend']._serialized_options = b'\202\323\344\223\002\014\022\n/OrderSend'
  _TRADINGHELPER.methods_by_name['OrderModify']._options = None
  _TRADINGHELPER.methods_by_name['OrderModify']._serialized_options = b'\202\323\344\223\002\016\022\014/OrderModify'
  _TRADINGHELPER.methods_by_name['OrderClose']._options = None
  _TRADINGHELPER.methods_by_name['OrderClose']._serialized_options = b'\202\323\344\223\002\r\022\013/OrderClose'
  _MRPC_ORDER_CLOSE_MODE._serialized_start=2155
  _MRPC_ORDER_CLOSE_MODE._serialized_end=2275
  _TMT5_ENUM_ORDER_TYPE._serialized_start=2278
  _TMT5_ENUM_ORDER_TYPE._serialized_end=2578
  _TMT5_ENUM_ORDER_TYPE_TIME._serialized_start=2581
  _TMT5_ENUM_ORDER_TYPE_TIME._serialized_end=2724
  _ORDERCLOSEREQUEST._serialized_start=136
  _ORDERCLOSEREQUEST._serialized_end=205
  _ORDERCLOSEREPLY._serialized_start=207
  _ORDERCLOSEREPLY._serialized_end=320
  _ORDERCLOSEDATA._serialized_start=323
  _ORDERCLOSEDATA._serialized_end=484
  _ORDERMODIFYREQUEST._serialized_start=487
  _ORDERMODIFYREQUEST._serialized_end=852
  _ORDERMODIFYREPLY._serialized_start=854
  _ORDERMODIFYREPLY._serialized_end=969
  _ORDERMODIFYDATA._serialized_start=972
  _ORDERMODIFYDATA._serialized_end=1227
  _ORDERSENDREQUEST._serialized_start=1230
  _ORDERSENDREQUEST._serialized_end=1784
  _ORDERSENDREPLY._serialized_start=1786
  _ORDERSENDREPLY._serialized_end=1897
  _ORDERSENDDATA._serialized_start=1900
  _ORDERSENDDATA._serialized_end=2153
  _TRADINGHELPER._serialized_start=2727
  _TRADINGHELPER._serialized_end=3039
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-health-check.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmt5-term-api-health-check.proto\x12\x0cmt5_term_api\"\x16\n\x14StopListeningRequest\"\x14\n\x12StopListeningReply\"\x14\n\x12HealthCheckRequest\"O\n\x10HealthCheckReply\x12\x1e\n\x16is_connected_to_server\x18\x01 \x01(\x08\x12\x1b\n\x13server_time_seconds\x18\x02 \x01(\x03\x32\xaa\x01\n\x06Health\x12I\n\x05\x43heck\x12 .mt5_term_api.HealthCheckRequest\x1a\x1e.mt5_term_api.HealthCheckReply\x12U\n\rStopListening\x12\".mt5_term_api.StopListeningRequest\x1a .mt5_term_api.StopListeningReplyBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_health_check_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _STOPLISTENINGREQUEST._serialized_start=49
  _STOPLISTENINGREQUEST._serialized_end=71
  _STOPLISTENINGREPLY._serialized_start=73
  _STOPLISTENINGREPLY._serialized_end=93
  _HEALTHCHECKREQUEST._serialized_start=95
  _HEALTHCHECKREQUEST._serialized_end=115
  _HEALTHCHECKREPLY._serialized_start=117
  _HEALTHCHECKREPLY._serialized_end=196
  _HEALTH._serialized_start=199
  _HEALTH._serialized_end=369
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import mt5_term_api_subscriptions_pb2 as mt5__term__api__subscriptions__pb2


class SubscriptionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.OnSymbolTick = channel.unary_stream(
                '/mt5_term_api.SubscriptionService/OnSymbolTick',
                request_serializer=mt5__term__api__subscriptions__pb2.OnSymbolTickRequest.SerializeToString,
                response_deserializer=mt5__term__api__subscriptions__pb2.OnSymbolTickReply.FromString,
                )
        self.OnTrade = channel.unary_stream(
                '/mt5_term_api.SubscriptionService/OnTrade',
                request_serializer=mt5__term__api__subscriptions__pb2.OnTradeRequest.SerializeToString,
                response_deserializer=mt5__term__api__subscriptions__pb2.OnTradeReply.FromString,
                )
        self.OnPositionProfit = channel.unary_stream(
                '/mt5_term_api.SubscriptionService/OnPositionProfit',
                request_serializer=mt5__term__api__subscriptions__pb2.OnPositionProfitRequest.SerializeToString,
                response_deserializer=mt5__term__api__subscriptions__pb2.OnPositionProfitReply.FromString,
                )
        self.OnPositionsAndPendingOrdersTickets = channel.unary_stream(
                '/mt5_term_api.SubscriptionService/OnPositionsAndPendingOrdersTickets',
                request_serializer=mt5__term__api__subscriptions__pb2.OnPositionsAndPendingOrdersTicketsRequest.SerializeToString,
                response_deserializer=mt5__term__api__subscriptions__pb2.OnPositionsAndPendingOrdersTicketsReply.FromString,
                )
        self.OnTradeTransaction = channel.unary_stream(
                '/mt5_term_api.SubscriptionService/OnTradeTransaction',
                request_serializer=mt5__term__api__subscriptions__pb2.OnTradeTransactionRequest.SerializeToString,
                response_deserializer=mt5__term__api__subscriptions__pb2.OnTradeTransactionReply.FromString,
                )


class SubscriptionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def OnSymbolTick(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnTrade(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnPositionProfit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnPositionsAndPendingOrdersTickets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnTradeTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SubscriptionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'OnSymbolTick': grpc.unary_stream_rpc_method_handler(
                    servicer.OnSymbolTick,
                    request_deserializer=mt5__term__api__subscriptions__pb2.OnSymbolTickRequest.FromString,
                    response_serializer=mt5__term__api__subscriptions__pb2.OnSymbolTickReply.SerializeToString,
            ),
            'OnTrade': grpc.unary_stream_rpc_method_handler(
                    servicer.OnTrade,
                    request_deserializer=mt5__term__api__subscriptions__pb2.OnTradeRequest.FromString,
                    response_serializer=mt5__term__api__subscriptions__pb2.OnTradeReply.SerializeToString,
            ),
            'OnPositionProfit': grpc.unary_stream_rpc_method_handler(
                    servicer.OnPositionProfit,
                    request_deserializer=mt5__term__api__subscriptions__pb2.OnPositionProfitRequest.FromString,
                    response_serializer=mt5__term__api__subscriptions__pb2.OnPositionProfitReply.SerializeToString,
            ),
            'OnPositionsAndPendingOrdersTickets': grpc.unary_stream_rpc_method_handler(
                    servicer.OnPositionsAndPendingOrdersTickets,
                    request_deserializer=mt5__term__api__subscriptions__pb2.OnPositionsAndPendingOrdersTicketsRequest.FromString,
                    response_serializer=mt5__term__api__subscriptions__pb2.OnPositionsAndPendingOrdersTicketsReply.SerializeToString,
            ),
            'OnTradeTransaction': grpc.unary_stream_rpc_method_handler(
                    servicer.OnTradeTransaction,
                    request_deserializer=mt5__term__api__subscriptions__pb2.OnTradeTransactionRequest.FromString,
                    response_serializer=mt5__term__api__subscriptions__pb2.OnTradeTransactionReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'mt5_term_api.SubscriptionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SubscriptionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def OnSymbolTick(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/mt5_term_api.SubscriptionService/OnSymbolTick',
            mt5__term__api__subscriptions__pb2.OnSymbolTickRequest.SerializeToString,
            mt5__term__api__subscriptions__pb2.OnSymbolTickReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnTrade(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/mt5_term_api.SubscriptionService/OnTrade',
            mt5__term__api__subscriptions__pb2.OnTradeRequest.SerializeToString,
            mt5__term__api__subscriptions__pb2.OnTradeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnPositionProfit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/mt5_term_api.SubscriptionService/OnPositionProfit',
            mt5__term__api__subscriptions__pb2.OnPositionProfitRequest.SerializeToString,
            mt5__term__api__subscriptions__pb2.OnPositionProfitReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnPositionsAndPendingOrdersTickets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/mt5_term_api.SubscriptionService/OnPositionsAndPendingOrdersTickets',
            mt5__term__api__subscriptions__pb2.OnPositionsAndPendingOrdersTicketsRequest.SerializeToString,
            mt5__term__api__subscriptions__pb2.OnPositionsAndPendingOrdersTicketsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnTradeTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/mt5_term_api.SubscriptionService/OnTradeTransaction',
            mt5__term__api__subscriptions__pb2.OnTradeTransactionRequest.SerializeToString,
            mt5__term__api__subscriptions__pb2.OnTradeTransactionReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mrpc-mt5-error.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14mrpc-mt5-error.proto\x12\x0cmt5_term_api\"\xc2\x03\n\x05\x45rror\x12%\n\x04type\x18\x01 \x01(\x0e\x32\x17.mt5_term_api.ErrorType\x12\x12\n\nerror_code\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x32\n\x0emql_error_code\x18\x04 \x01(\x0e\x32\x1a.mt5_term_api.MqlErrorCode\x12\x1a\n\x12mql_error_int_code\x18\x05 \x01(\x05\x12\x1d\n\x15mql_error_description\x18\x06 \x01(\t\x12=\n\x14mql_error_trade_code\x18\x07 \x01(\x0e\x32\x1f.mt5_term_api.MqlErrorTradeCode\x12 \n\x18mql_error_trade_int_code\x18\x08 \x01(\x05\x12#\n\x1bmql_error_trade_description\x18\t \x01(\t\x12\x13\n\x0bstack_trace\x18\n \x01(\t\x12\x19\n\x11\x63ommand_type_name\x18\x0b \x01(\t\x12\x11\n\tcommandId\x18\x0c \x01(\x03\x12/\n\nproperties\x18\r \x03(\x0b\x32\x1b.mt5_term_api.ErrorProperty\"?\n\rErrorProperty\x12\x15\n\rerror_arg_key\x18\x01 \x01(\t\x12\x17\n\x0f\x65rror_arg_value\x18\x02 \x01(\t\"h\n\x0bLogFileInfo\x12\'\n\x08log_type\x18\x01 \x01(\x0e\x32\x15.mt5_term_api.LogType\x12\x11\n\tfull_path\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t*\x82\x02\n\tErrorType\x12\r\n\tUNDEFINED\x10\x00\x12\x08\n\x04MRPC\x10\x01\x12\x13\n\x0fMRPC_VALIDATION\x10\x02\x12\x10\n\x0cMRPC_TIMEOUT\x10\x03\x12\x18\n\x14TERMINAL_API_TIMEOUT\x10\x04\x12\x1b\n\x17TERMINAL_API_GET_PARAMS\x10\x05\x12\x1b\n\x17TERMINAL_API_SET_RESULT\x10\x06\x12\x1b\n\x17TERMINAL_API_UNEXPECTED\x10\x07\x12\x11\n\rMQL_EXECUTION\x10\x08\x12\x18\n\x14MQL_CUSTOM_EXECUTION\x10\t\x12\x17\n\x13MQL_TRADE_EXECUTION\x10\n*)\n\x07LogType\x12\n\n\x06Global\x10\x00\x12\x08\n\x04MQL5\x10\x01\x12\x08\n\x04MQL4\x10\x02*\xe3\x31\n\x0cMqlErrorCode\x12\x0f\n\x0b\x45RR_SUCCESS\x10\x00\x12\x17\n\x12\x45RR_INTERNAL_ERROR\x10\xa1\x1f\x12!\n\x1c\x45RR_WRONG_INTERNAL_PARAMETER\x10\xa2\x1f\x12\x1a\n\x15\x45RR_INVALID_PARAMETER\x10\xa3\x1f\x12\x1a\n\x15\x45RR_NOT_ENOUGH_MEMORY\x10\xa4\x1f\x12#\n\x1e\x45RR_STRUCT_WITHOBJECTS_ORCLASS\x10\xa5\x1f\x12\x16\n\x11\x45RR_INVALID_ARRAY\x10\xa6\x1f\x12\x1b\n\x16\x45RR_ARRAY_RESIZE_ERROR\x10\xa7\x1f\x12\x1c\n\x17\x45RR_STRING_RESIZE_ERROR\x10\xa8\x1f\x12\x1e\n\x19\x45RR_NOTINITIALIZED_STRING\x10\xa9\x1f\x12\x19\n\x14\x45RR_INVALID_DATETIME\x10\xaa\x1f\x12\x17\n\x12\x45RR_ARRAY_BAD_SIZE\x10\xab\x1f\x12\x18\n\x13\x45RR_INVALID_POINTER\x10\xac\x1f\x12\x1d\n\x18\x45RR_INVALID_POINTER_TYPE\x10\xad\x1f\x12\x1d\n\x18\x45RR_FUNCTION_NOT_ALLOWED\x10\xae\x1f\x12!\n\x1c\x45RR_RESOURCE_NAME_DUPLICATED\x10\xaf\x1f\x12\x1b\n\x16\x45RR_RESOURCE_NOT_FOUND\x10\xb0\x1f\x12\"\n\x1d\x45RR_RESOURCE_UNSUPPORTED_TYPE\x10\xb1\x1f\x12\"\n\x1d\x45RR_RESOURCE_NAME_IS_TOO_LONG\x10\xb2\x1f\x12\x16\n\x11\x45RR_MATH_OVERFLOW\x10\xb3\x1f\x12\x14\n\x0f\x45RR_SLEEP_ERROR\x10\xb4\x1f\x12\x18\n\x13\x45RR_PROGRAM_STOPPED\x10\xb6\x1f\x12\x15\n\x10\x45RR_INVALID_TYPE\x10\xb7\x1f\x12\x17\n\x12\x45RR_INVALID_HANDLE\x10\xb8\x1f\x12\x19\n\x14\x45RR_TOO_MANY_OBJECTS\x10\xb9\x1f\x12\x17\n\x12\x45RR_CHART_WRONG_ID\x10\x85 \x12\x17\n\x12\x45RR_CHART_NO_REPLY\x10\x86 \x12\x18\n\x13\x45RR_CHART_NOT_FOUND\x10\x87 \x12\x18\n\x13\x45RR_CHART_NO_EXPERT\x10\x88 \x12\x1a\n\x15\x45RR_CHART_CANNOT_OPEN\x10\x89 \x12\x1c\n\x17\x45RR_CHART_CANNOT_CHANGE\x10\x8a \x12\x1e\n\x19\x45RR_CHART_WRONG_PARAMETER\x10\x8b \x12\"\n\x1d\x45RR_CHART_CANNOT_CREATE_TIMER\x10\x8c \x12\x1d\n\x18\x45RR_CHART_WRONG_PROPERTY\x10\x8d \x12 \n\x1b\x45RR_CHART_SCREENSHOT_FAILED\x10\x8e \x12\x1e\n\x19\x45RR_CHART_NAVIGATE_FAILED\x10\x8f \x12\x1e\n\x19\x45RR_CHART_TEMPLATE_FAILED\x10\x90 \x12\x1f\n\x1a\x45RR_CHART_WINDOW_NOT_FOUND\x10\x91 \x12#\n\x1e\x45RR_CHART_INDICATOR_CANNOT_ADD\x10\x92 \x12#\n\x1e\x45RR_CHART_INDICATOR_CANNOT_DEL\x10\x93 \x12\"\n\x1d\x45RR_CHART_INDICATOR_NOT_FOUND\x10\x94 \x12\x15\n\x10\x45RR_OBJECT_ERROR\x10\xe9 \x12\x19\n\x14\x45RR_OBJECT_NOT_FOUND\x10\xea \x12\x1e\n\x19\x45RR_OBJECT_WRONG_PROPERTY\x10\xeb \x12\x1e\n\x19\x45RR_OBJECT_GETDATE_FAILED\x10\xec \x12\x1f\n\x1a\x45RR_OBJECT_GETVALUE_FAILED\x10\xed \x12\x1e\n\x19\x45RR_MARKET_UNKNOWN_SYMBOL\x10\xcd!\x12\x1c\n\x17\x45RR_MARKET_NOT_SELECTED\x10\xce!\x12\x1e\n\x19\x45RR_MARKET_WRONG_PROPERTY\x10\xcf!\x12 \n\x1b\x45RR_MARKET_LASTTIME_UNKNOWN\x10\xd0!\x12\x1c\n\x17\x45RR_MARKET_SELECT_ERROR\x10\xd1!\x12\x1c\n\x17\x45RR_MARKET_SELECT_LIMIT\x10\xd2!\x12\x1d\n\x18\x45RR_MARKET_SESSION_INDEX\x10\xd3!\x12\x1a\n\x15\x45RR_HISTORY_NOT_FOUND\x10\xb1\"\x12\x1f\n\x1a\x45RR_HISTORY_WRONG_PROPERTY\x10\xb2\"\x12\x18\n\x13\x45RR_HISTORY_TIMEOUT\x10\xb3\"\x12\x1b\n\x16\x45RR_HISTORY_BARS_LIMIT\x10\xb4\"\x12\x1c\n\x17\x45RR_HISTORY_LOAD_ERRORS\x10\xb5\"\x12\x1d\n\x18\x45RR_HISTORY_SMALL_BUFFER\x10\xb7\"\x12!\n\x1c\x45RR_GLOBALVARIABLE_NOT_FOUND\x10\x95#\x12\x1e\n\x19\x45RR_GLOBALVARIABLE_EXISTS\x10\x96#\x12$\n\x1f\x45RR_GLOBALVARIABLE_NOT_MODIFIED\x10\x97#\x12\"\n\x1d\x45RR_GLOBALVARIABLE_CANNOTREAD\x10\x98#\x12#\n\x1e\x45RR_GLOBALVARIABLE_CANNOTWRITE\x10\x99#\x12\x19\n\x14\x45RR_MAIL_SEND_FAILED\x10\x9e#\x12\x1a\n\x15\x45RR_PLAY_SOUND_FAILED\x10\x9f#\x12\x1c\n\x17\x45RR_MQL5_WRONG_PROPERTY\x10\xa0#\x12 \n\x1b\x45RR_TERMINAL_WRONG_PROPERTY\x10\xa1#\x12\x18\n\x13\x45RR_FTP_SEND_FAILED\x10\xa2#\x12!\n\x1c\x45RR_NOTIFICATION_SEND_FAILED\x10\xa3#\x12%\n ERR_NOTIFICATION_WRONG_PARAMETER\x10\xa4#\x12$\n\x1f\x45RR_NOTIFICATION_WRONG_SETTINGS\x10\xa5#\x12\"\n\x1d\x45RR_NOTIFICATION_TOO_FREQUENT\x10\xa6#\x12\x15\n\x10\x45RR_FTP_NOSERVER\x10\xa7#\x12\x14\n\x0f\x45RR_FTP_NOLOGIN\x10\xa8#\x12\x17\n\x12\x45RR_FTP_FILE_ERROR\x10\xa9#\x12\x1b\n\x16\x45RR_FTP_CONNECT_FAILED\x10\xaa#\x12\x16\n\x11\x45RR_FTP_CHANGEDIR\x10\xab#\x12\x1a\n\x15\x45RR_BUFFERS_NO_MEMORY\x10\xf9#\x12\x1c\n\x17\x45RR_BUFFERS_WRONG_INDEX\x10\xfa#\x12\x1e\n\x19\x45RR_CUSTOM_WRONG_PROPERTY\x10\xfb#\x12\x1f\n\x1a\x45RR_ACCOUNT_WRONG_PROPERTY\x10\xdd$\x12\x1d\n\x18\x45RR_TRADE_WRONG_PROPERTY\x10\x8f%\x12\x17\n\x12\x45RR_TRADE_DISABLED\x10\x90%\x12!\n\x1c\x45RR_TRADE_POSITION_NOT_FOUND\x10\x91%\x12\x1e\n\x19\x45RR_TRADE_ORDER_NOT_FOUND\x10\x92%\x12\x1d\n\x18\x45RR_TRADE_DEAL_NOT_FOUND\x10\x93%\x12\x1a\n\x15\x45RR_TRADE_SEND_FAILED\x10\x94%\x12\x1a\n\x15\x45RR_TRADE_CALC_FAILED\x10\x96%\x12!\n\x1c\x45RR_INDICATOR_UNKNOWN_SYMBOL\x10\xc1%\x12 \n\x1b\x45RR_INDICATOR_CANNOT_CREATE\x10\xc2%\x12\x1c\n\x17\x45RR_INDICATOR_NO_MEMORY\x10\xc3%\x12\x1f\n\x1a\x45RR_INDICATOR_CANNOT_APPLY\x10\xc4%\x12\x1d\n\x18\x45RR_INDICATOR_CANNOT_ADD\x10\xc5%\x12!\n\x1c\x45RR_INDICATOR_DATA_NOT_FOUND\x10\xc6%\x12\x1f\n\x1a\x45RR_INDICATOR_WRONG_HANDLE\x10\xc7%\x12#\n\x1e\x45RR_INDICATOR_WRONG_PARAMETERS\x10\xc8%\x12\x19\n\x14\x45RR_BOOKS_CANNOT_ADD\x10\xa5&\x12\x1c\n\x17\x45RR_BOOKS_CANNOT_DELETE\x10\xa6&\x12\x19\n\x14\x45RR_BOOKS_CANNOT_GET\x10\xa7&\x12\x1f\n\x1a\x45RR_BOOKS_CANNOT_SUBSCRIBE\x10\xa8&\x12\x17\n\x12\x45RR_TOO_MANY_FILES\x10\x89\'\x12\x17\n\x12\x45RR_WRONG_FILENAME\x10\x8a\'\x12\x1a\n\x15\x45RR_TOO_LONG_FILENAME\x10\x8b\'\x12\x19\n\x14\x45RR_CANNOT_OPEN_FILE\x10\x8c\'\x12\x1f\n\x1a\x45RR_FILE_CACHEBUFFER_ERROR\x10\x8d\'\x12\x1b\n\x16\x45RR_CANNOT_DELETE_FILE\x10\x8e\'\x12\x1b\n\x16\x45RR_INVALID_FILEHANDLE\x10\x8f\'\x12\x19\n\x14\x45RR_WRONG_FILEHANDLE\x10\x90\'\x12\x17\n\x12\x45RR_NO_STRING_DATE\x10\xa6\'\x12\x1a\n\x15\x45RR_WRONG_STRING_DATE\x10\xa7\'\x12\x1a\n\x15\x45RR_WRONG_STRING_TIME\x10\xa8\'\x12\x1a\n\x15\x45RR_STRING_TIME_ERROR\x10\xa9\'\x12\x1d\n\x18\x45RR_STRING_OUT_OF_MEMORY\x10\xaa\'\x12\x1c\n\x17\x45RR_INCOMPATIBLE_ARRAYS\x10\xba\'\x12\x1d\n\x18\x45RR_SMALL_ASSERIES_ARRAY\x10\xbb\'\x12\x14\n\x0f\x45RR_SMALL_ARRAY\x10\xbc\'\x12\x17\n\x12\x45RR_ZEROSIZE_ARRAY\x10\xbd\'\x12\x1b\n\x16\x45RR_NUMBER_ARRAYS_ONLY\x10\xbe\'\x12\x1d\n\x18\x45RR_OPENCL_NOT_SUPPORTED\x10\xec\'\x12\x18\n\x13\x45RR_OPENCL_INTERNAL\x10\xed\'\x12\x1e\n\x19\x45RR_OPENCL_INVALID_HANDLE\x10\xee\'\x12\x1e\n\x19\x45RR_OPENCL_CONTEXT_CREATE\x10\xef\'\x12\x1c\n\x17\x45RR_OPENCL_QUEUE_CREATE\x10\xf0\'\x12\x1e\n\x19\x45RR_OPENCL_PROGRAM_CREATE\x10\xf1\'\x12$\n\x1f\x45RR_OPENCL_TOO_LONG_KERNEL_NAME\x10\xf2\'\x12\x1d\n\x18\x45RR_OPENCL_KERNEL_CREATE\x10\xf3\'\x12$\n\x1f\x45RR_OPENCL_SET_KERNEL_PARAMETER\x10\xf4\'\x12\x17\n\x12\x45RR_OPENCL_EXECUTE\x10\xf5\'\x12!\n\x1c\x45RR_OPENCL_WRONG_BUFFER_SIZE\x10\xf6\'\x12#\n\x1e\x45RR_OPENCL_WRONG_BUFFER_OFFSET\x10\xf7\'\x12\x1d\n\x18\x45RR_OPENCL_BUFFER_CREATE\x10\xf8\'\x12 \n\x1b\x45RR_OPENCL_TOO_MANY_OBJECTS\x10\xf9\'\x12\x1c\n\x17\x45RR_OPENCL_SELECTDEVICE\x10\xfa\'\x12\x1a\n\x15\x45RR_DATABASE_INTERNAL\x10\x80(\x12 \n\x1b\x45RR_DATABASE_INVALID_HANDLE\x10\x81(\x12\"\n\x1d\x45RR_DATABASE_TOO_MANY_OBJECTS\x10\x82(\x12\x19\n\x14\x45RR_DATABASE_CONNECT\x10\x83(\x12\x19\n\x14\x45RR_DATABASE_EXECUTE\x10\x84(\x12\x19\n\x14\x45RR_DATABASE_PREPARE\x10\x85(\x12\x1e\n\x19\x45RR_DATABASE_NO_MORE_DATA\x10\x86(\x12\x16\n\x11\x45RR_DATABASE_STEP\x10\x87(\x12\x1b\n\x16\x45RR_DATABASE_NOT_READY\x10\x88(\x12!\n\x1c\x45RR_DATABASE_BIND_PARAMETERS\x10\x89(\x12#\n\x1e\x45RR_WEBREQUEST_INVALID_ADDRESS\x10\xd0(\x12\"\n\x1d\x45RR_WEBREQUEST_CONNECT_FAILED\x10\xd1(\x12\x1b\n\x16\x45RR_WEBREQUEST_TIMEOUT\x10\xd2(\x12\"\n\x1d\x45RR_WEBREQUEST_REQUEST_FAILED\x10\xd3(\x12 \n\x1b\x45RR_NETSOCKET_INVALIDHANDLE\x10\x96)\x12\"\n\x1d\x45RR_NETSOCKET_TOO_MANY_OPENED\x10\x97)\x12!\n\x1c\x45RR_NETSOCKET_CANNOT_CONNECT\x10\x98)\x12\x1b\n\x16\x45RR_NETSOCKET_IO_ERROR\x10\x99)\x12#\n\x1e\x45RR_NETSOCKET_HANDSHAKE_FAILED\x10\x9a)\x12!\n\x1c\x45RR_NETSOCKET_NO_CERTIFICATE\x10\x9b)\x12\x1a\n\x15\x45RR_NOT_CUSTOM_SYMBOL\x10\xb4)\x12!\n\x1c\x45RR_CUSTOM_SYMBOL_WRONG_NAME\x10\xb5)\x12 \n\x1b\x45RR_CUSTOM_SYMBOL_NAME_LONG\x10\xb6)\x12 \n\x1b\x45RR_CUSTOM_SYMBOL_PATH_LONG\x10\xb7)\x12\x1c\n\x17\x45RR_CUSTOM_SYMBOL_EXIST\x10\xb8)\x12\x1c\n\x17\x45RR_CUSTOM_SYMBOL_ERROR\x10\xb9)\x12\x1f\n\x1a\x45RR_CUSTOM_SYMBOL_SELECTED\x10\xba)\x12%\n ERR_CUSTOM_SYMBOL_PROPERTY_WRONG\x10\xbb)\x12&\n!ERR_CUSTOM_SYMBOL_PARAMETER_ERROR\x10\xbc)\x12%\n ERR_CUSTOM_SYMBOL_PARAMETER_LONG\x10\xbd)\x12!\n\x1c\x45RR_CUSTOM_TICKS_WRONG_ORDER\x10\xbe)\x12\x1b\n\x16\x45RR_CALENDAR_MORE_DATA\x10\x98*\x12\x19\n\x14\x45RR_CALENDAR_TIMEOUT\x10\x99*\x12\x19\n\x14\x45RR_CALENDAR_NO_DATA\x10\x9a*\x12\x17\n\x12\x45RR_DATABASE_ERROR\x10\xe1+\x12\x17\n\x12\x45RR_DATABASE_LOGIC\x10\xe2+\x12\x16\n\x11\x45RR_DATABASE_PERM\x10\xe3+\x12\x17\n\x12\x45RR_DATABASE_ABORT\x10\xe4+\x12\x16\n\x11\x45RR_DATABASE_BUSY\x10\xe5+\x12\x18\n\x13\x45RR_DATABASE_LOCKED\x10\xe6+\x12\x17\n\x12\x45RR_DATABASE_NOMEM\x10\xe7+\x12\x1a\n\x15\x45RR_DATABASE_READONLY\x10\xe8+\x12\x1b\n\x16\x45RR_DATABASE_INTERRUPT\x10\xe9+\x12\x17\n\x12\x45RR_DATABASE_IOERR\x10\xea+\x12\x19\n\x14\x45RR_DATABASE_CORRUPT\x10\xeb+\x12\x1a\n\x15\x45RR_DATABASE_NOTFOUND\x10\xec+\x12\x16\n\x11\x45RR_DATABASE_FULL\x10\xed+\x12\x1a\n\x15\x45RR_DATABASE_CANTOPEN\x10\xee+\x12\x1a\n\x15\x45RR_DATABASE_PROTOCOL\x10\xef+\x12\x17\n\x12\x45RR_DATABASE_EMPTY\x10\xf0+\x12\x18\n\x13\x45RR_DATABASE_SCHEMA\x10\xf1+\x12\x18\n\x13\x45RR_DATABASE_TOOBIG\x10\xf2+\x12\x1c\n\x17\x45RR_DATABASE_CONSTRAINT\x10\xf3+\x12\x1a\n\x15\x45RR_DATABASE_MISMATCH\x10\xf4+\x12\x18\n\x13\x45RR_DATABASE_MISUSE\x10\xf5+\x12\x17\n\x12\x45RR_DATABASE_NOLFS\x10\xf6+\x12\x16\n\x11\x45RR_DATABASE_AUTH\x10\xf7+\x12\x18\n\x13\x45RR_DATABASE_FORMAT\x10\xf8+\x12\x17\n\x12\x45RR_DATABASE_RANGE\x10\xf9+\x12\x18\n\x13\x45RR_DATABASE_NOTADB\x10\xfa+\x12\x18\n\x13\x45RR_MATRIX_INTERNAL\x10\xc4,\x12\x1f\n\x1a\x45RR_MATRIX_NOT_INITIALIZED\x10\xc5,\x12\x1c\n\x17\x45RR_MATRIX_INCONSISTENT\x10\xc6,\x12\x1c\n\x17\x45RR_MATRIX_INVALID_SIZE\x10\xc7,\x12\x1c\n\x17\x45RR_MATRIX_INVALID_TYPE\x10\xc8,\x12 \n\x1b\x45RR_MATRIX_FUNC_NOT_ALLOWED\x10\xc9,\x12\x1c\n\x17\x45RR_MATRIX_CONTAINS_NAN\x10\xca,\x12\x16\n\x11\x45RR_ONNX_INTERNAL\x10\xa8-\x12\x1d\n\x18\x45RR_ONNX_NOT_INITIALIZED\x10\xa9-\x12\x1b\n\x16\x45RR_ONNX_NOT_SUPPORTED\x10\xaa-\x12\x18\n\x13\x45RR_ONNX_RUN_FAILED\x10\xab-\x12&\n!ERR_ONNX_INVALID_PARAMETERS_COUNT\x10\xac-\x12\x1f\n\x1a\x45RR_ONNX_INVALID_PARAMETER\x10\xad-\x12$\n\x1f\x45RR_ONNX_INVALID_PARAMETER_TYPE\x10\xae-\x12$\n\x1f\x45RR_ONNX_INVALID_PARAMETER_SIZE\x10\xaf-\x12\x1d\n\x18\x45RR_ONNX_WRONG_DIMENSION\x10\xb0-\x12\x1a\n\x14\x45RR_USER_ERROR_FIRST\x10\x80\x80\x04*\xdd\n\n\x11MqlErrorTradeCode\x12\x19\n\x15TRADE_RETCODE_SUCCESS\x10\x00\x12\x1a\n\x15TRADE_RETCODE_REQUOTE\x10\x94N\x12\x19\n\x14TRADE_RETCODE_REJECT\x10\x96N\x12\x19\n\x14TRADE_RETCODE_CANCEL\x10\x97N\x12\x19\n\x14TRADE_RETCODE_PLACED\x10\x98N\x12\x17\n\x12TRADE_RETCODE_DONE\x10\x99N\x12\x1f\n\x1aTRADE_RETCODE_DONE_PARTIAL\x10\x9aN\x12\x18\n\x13TRADE_RETCODE_ERROR\x10\x9bN\x12\x1a\n\x15TRADE_RETCODE_TIMEOUT\x10\x9cN\x12\x1a\n\x15TRADE_RETCODE_INVALID\x10\x9dN\x12!\n\x1cTRADE_RETCODE_INVALID_VOLUME\x10\x9eN\x12 \n\x1bTRADE_RETCODE_INVALID_PRICE\x10\x9fN\x12 \n\x1bTRADE_RETCODE_INVALID_STOPS\x10\xa0N\x12!\n\x1cTRADE_RETCODE_TRADE_DISABLED\x10\xa1N\x12 \n\x1bTRADE_RETCODE_MARKET_CLOSED\x10\xa2N\x12\x1b\n\x16TRADE_RETCODE_NO_MONEY\x10\xa3N\x12 \n\x1bTRADE_RETCODE_PRICE_CHANGED\x10\xa4N\x12\x1c\n\x17TRADE_RETCODE_PRICE_OFF\x10\xa5N\x12%\n TRADE_RETCODE_INVALID_EXPIRATION\x10\xa6N\x12 \n\x1bTRADE_RETCODE_ORDER_CHANGED\x10\xa7N\x12$\n\x1fTRADE_RETCODE_TOO_MANY_REQUESTS\x10\xa8N\x12\x1d\n\x18TRADE_RETCODE_NO_CHANGES\x10\xa9N\x12%\n TRADE_RETCODE_SERVER_DISABLES_AT\x10\xaaN\x12%\n TRADE_RETCODE_CLIENT_DISABLES_AT\x10\xabN\x12\x19\n\x14TRADE_RETCODE_LOCKED\x10\xacN\x12\x19\n\x14TRADE_RETCODE_FROZEN\x10\xadN\x12\x1f\n\x1aTRADE_RETCODE_INVALID_FILL\x10\xaeN\x12\x1d\n\x18TRADE_RETCODE_CONNECTION\x10\xafN\x12\x1c\n\x17TRADE_RETCODE_ONLY_REAL\x10\xb0N\x12\x1f\n\x1aTRADE_RETCODE_LIMIT_ORDERS\x10\xb1N\x12\x1f\n\x1aTRADE_RETCODE_LIMIT_VOLUME\x10\xb2N\x12 \n\x1bTRADE_RETCODE_INVALID_ORDER\x10\xb3N\x12\"\n\x1dTRADE_RETCODE_POSITION_CLOSED\x10\xb4N\x12\'\n\"TRADE_RETCODE_INVALID_CLOSE_VOLUME\x10\xb6N\x12$\n\x1fTRADE_RETCODE_CLOSE_ORDER_EXIST\x10\xb7N\x12\"\n\x1dTRADE_RETCODE_LIMIT_POSITIONS\x10\xb8N\x12 \n\x1bTRADE_RETCODE_REJECT_CANCEL\x10\xb9N\x12\x1c\n\x17TRADE_RETCODE_LONG_ONLY\x10\xbaN\x12\x1d\n\x18TRADE_RETCODE_SHORT_ONLY\x10\xbbN\x12\x1d\n\x18TRADE_RETCODE_CLOSE_ONLY\x10\xbcN\x12\x1d\n\x18TRADE_RETCODE_FIFO_CLOSE\x10\xbdN\x12#\n\x1eTRADE_RETCODE_HEDGE_PROHIBITED\x10\xbeNB3Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/gob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mrpc_mt5_error_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go'
  _ERRORTYPE._serialized_start=663
  _ERRORTYPE._serialized_end=921
  _LOGTYPE._serialized_start=923
  _LOGTYPE._serialized_end=964
  _MQLERRORCODE._serialized_start=967
  _MQLERRORCODE._serialized_end=7338
  _MQLERRORTRADECODE._serialized_start=7341
  _MQLERRORTRADECODE._serialized_end=8714
  _ERROR._serialized_start=39
  _ERROR._serialized_end=489
  _ERRORPROPERTY._serialized_start=491
  _ERRORPROPERTY._serialized_end=554
  _LOGFILEINFO._serialized_start=556
  _LOGFILEINFO._serialized_end=660
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mt5-term-api-connection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import mrpc_mt5_error_pb2 as mrpc__mt5__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dmt5-term-api-connection.proto\x12\x0cmt5_term_api\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x14mrpc-mt5-error.proto\"\x9e\x02\n\x10\x43onnectExRequest\x12\x0c\n\x04user\x18\x01 \x01(\x04\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x17\n\x0fmt_cluster_name\x18\x03 \x01(\t\x12\x1e\n\x11\x62\x61se_chart_symbol\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x37\n*terminal_readiness_waiting_timeout_seconds\x18\x05 \x01(\x05H\x01\x88\x01\x01\x12\x33\n\x0e\x65xperts_to_add\x18\x06 \x03(\x0b\x32\x1b.mt5_term_api.ExpertAdviserB\x14\n\x12_base_chart_symbolB-\n+_terminal_readiness_waiting_timeout_seconds\"m\n\x0e\x43onnectExReply\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x19.mt5_term_api.ConnectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xb2\x01\n\x10ReconnectRequest\x12\x1f\n\x12\x66orce_reconnection\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x37\n*terminal_readiness_waiting_timeout_seconds\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x15\n\x13_force_reconnectionB-\n+_terminal_readiness_waiting_timeout_seconds\"o\n\x0eReconnectReply\x12+\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1b.mt5_term_api.ReconnectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"\xe1\x01\n\rReconnectData\x12\x1e\n\x16terminal_was_recreated\x18\x01 \x01(\x08\x12\x31\n\rterminal_type\x18\x02 \x01(\x0e\x32\x1a.mt5_term_api.TerminalType\x12\x1e\n\x16terminal_instance_guid\x18\x03 \x01(\t\x12+\n#old_terminal_full_live_time_seconds\x18\x04 \x01(\x03\x12\x30\n\rold_log_files\x18\x05 \x03(\x0b\x32\x19.mt5_term_api.LogFileInfo\"\xe7\x02\n\x0e\x43onnectRequest\x12\x0c\n\x04user\x18\x01 \x01(\x04\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x1e\n\x11\x62\x61se_chart_symbol\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\'\n\x1await_for_terminal_is_alive\x18\x06 \x01(\x08H\x01\x88\x01\x01\x12\x37\n*terminal_readiness_waiting_timeout_seconds\x18\x07 \x01(\x05H\x02\x88\x01\x01\x12\x33\n\x0e\x65xperts_to_add\x18\x08 \x03(\x0b\x32\x1b.mt5_term_api.ExpertAdviserB\x14\n\x12_base_chart_symbolB\x1d\n\x1b_wait_for_terminal_is_aliveB-\n+_terminal_readiness_waiting_timeout_seconds\"8\n\rExpertAdviser\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66ile_content\x18\x02 \x01(\x0c\"k\n\x0c\x43onnectReply\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x19.mt5_term_api.ConnectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"`\n\x0b\x43onnectData\x12\x1e\n\x16terminal_instance_guid\x18\x01 \x01(\t\x12\x31\n\rterminal_type\x18\x03 \x01(\x0e\x32\x1a.mt5_term_api.TerminalType\"\xe9\x03\n\x13\x43onnectProxyRequest\x12\x0c\n\x04user\x18\x01 \x01(\x04\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x11\n\tproxyUser\x18\x05 \x01(\t\x12\x15\n\rproxyPassword\x18\x06 \x01(\t\x12\x11\n\tproxyHost\x18\x07 \x01(\t\x12\x11\n\tproxyPort\x18\x08 \x01(\r\x12+\n\tproxyType\x18\t \x01(\x0e\x32\x18.mt5_term_api.ProxyTypes\x12\x1e\n\x11\x62\x61se_chart_symbol\x18\n \x01(\tH\x00\x88\x01\x01\x12\'\n\x1await_for_terminal_is_alive\x18\x0b \x01(\x08H\x01\x88\x01\x01\x12\x37\n*terminal_readiness_waiting_timeout_seconds\x18\x0c \x01(\x05H\x02\x88\x01\x01\x12\x33\n\x0e\x65xperts_to_add\x18\r \x03(\x0b\x32\x1b.mt5_term_api.ExpertAdviserB\x14\n\x12_base_chart_symbolB\x1d\n\x1b_wait_for_terminal_is_aliveB-\n+_terminal_readiness_waiting_timeout_seconds\"u\n\x11\x43onnectProxyReply\x12.\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1e.mt5_term_api.ConnectProxyDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"`\n\x10\x43onnectProxyData\x12\x19\n\x11unique_identifier\x18\x01 \x01(\t\x12\x31\n\rterminal_type\x18\x02 \x01(\x0e\x32\x1a.mt5_term_api.TerminalType\"\x15\n\x13\x43heckConnectRequest\"u\n\x11\x43heckConnectReply\x12.\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1e.mt5_term_api.CheckConnectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"f\n\x10\x43heckConnectData\x12\x19\n\x11unique_identifier\x18\x01 \x01(\t\x12\x37\n\x0chealth_check\x18\x02 \x01(\x0b\x32!.mt5_term_api.TerminalHealthCheck\"\xa1\x02\n\x13TerminalHealthCheck\x12\x10\n\x08is_alive\x18\x01 \x01(\x08\x12\x32\n\x0c\x45rrorMessage\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tErrorCode\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nStackTrace\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x17has_authorization_error\x18\x05 \x01(\x08\x12\x14\n\x0c\x61pi_is_alive\x18\x06 \x01(\x08\x12*\n\"terminal_is_connected_to_mt_server\x18\x07 \x01(\x08\"\x13\n\x11\x44isconnectRequest\"q\n\x0f\x44isconnectReply\x12,\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.mt5_term_api.DisconnectDataH\x00\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.mt5_term_api.ErrorH\x00\x42\n\n\x08response\"K\n\x0e\x44isconnectData\x12\x19\n\x11unique_identifier\x18\x01 \x01(\t\x12\x1e\n\x16\x66ull_life_time_seconds\x18\x02 \x01(\x03*9\n\nProxyTypes\x12\x08\n\x04None\x10\x00\x12\t\n\x05Https\x10\x01\x12\n\n\x06Socks4\x10\x02\x12\n\n\x06Socks5\x10\x03* \n\x0cTerminalType\x12\x07\n\x03MT4\x10\x00\x12\x07\n\x03MT5\x10\x01\x32\xda\x04\n\nConnection\x12]\n\tConnectEx\x12\x1e.mt5_term_api.ConnectExRequest\x1a\x1c.mt5_term_api.ConnectExReply\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/ConnectEx\x12U\n\x07\x43onnect\x12\x1c.mt5_term_api.ConnectRequest\x1a\x1a.mt5_term_api.ConnectReply\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/Connect\x12i\n\x0c\x43onnectProxy\x12!.mt5_term_api.ConnectProxyRequest\x1a\x1f.mt5_term_api.ConnectProxyReply\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/ConnectProxy\x12i\n\x0c\x43heckConnect\x12!.mt5_term_api.CheckConnectRequest\x1a\x1f.mt5_term_api.CheckConnectReply\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/CheckConnect\x12\x61\n\nDisconnect\x12\x1f.mt5_term_api.DisconnectRequest\x1a\x1d.mt5_term_api.DisconnectReply\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/Disconnect\x12]\n\tReconnect\x12\x1e.mt5_term_api.ReconnectRequest\x1a\x1c.mt5_term_api.ReconnectReply\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/ReconnectBBZ1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\xaa\x02\x0cmt5_term_apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mt5_term_api_connection_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1git.mtapi.io/root/mrpc-proto.git/mt5/libraries/go\252\002\014mt5_term_api'
  _CONNECTION.methods_by_name['ConnectEx']._options = None
  _CONNECTION.methods_by_name['ConnectEx']._serialized_options = b'\202\323\344\223\002\014\022\n/ConnectEx'
  _CONNECTION.methods_by_name['Connect']._options = None
  _CONNECTION.methods_by_name['Connect']._serialized_options = b'\202\323\344\223\002\n\022\010/Connect'
  _CONNECTION.methods_by_name['ConnectProxy']._options = None
  _CONNECTION.methods_by_name['ConnectProxy']._serialized_options = b'\202\323\344\223\002\017\022\r/ConnectProxy'
  _CONNECTION.methods_by_name['CheckConnect']._options = None
  _CONNECTION.methods_by_name['CheckConnect']._serialized_options = b'\202\323\344\223\002\017\022\r/CheckConnect'
  _CONNECTION.methods_by_name['Disconnect']._options = None
  _CONNECTION.methods_by_name['Disconnect']._serialized_options = b'\202\323\344\223\002\r\022\013/Disconnect'
  _CONNECTION.methods_by_name['Reconnect']._options = None
  _CONNECTION.methods_by_name['Reconnect']._serialized_options = b'\202\323\344\223\002\014\022\n/Reconnect'
  _PROXYTYPES._serialized_start=3140
  _PROXYTYPES._serialized_end=3197
  _TERMINALTYPE._serialized_start=3199
  _TERMINALTYPE._serialized_end=3231
  _CONNECTEXREQUEST._serialized_start=132
  _CONNECTEXREQUEST._serialized_end=418
  _CONNECTEXREPLY._serialized_start=420
  _CONNECTEXREPLY._serialized_end=529
  _RECONNECTREQUEST._serialized_start=532
  _RECONNECTREQUEST._serialized_end=710
  _RECONNECTREPLY._serialized_start=712
  _RECONNECTREPLY._serialized_end=823
  _RECONNECTDATA._serialized_start=826
  _RECONNECTDATA._serialized_end=1051
  _CONNECTREQUEST._serialized_start=1054
  _CONNECTREQUEST._serialized_end=1413
  _EXPERTADVISER._serialized_start=1415
  _EXPERTADVISER._serialized_end=1471
  _CONNECTREPLY._serialized_start=1473
  _CONNECTREPLY._serialized_end=1580
  _CONNECTDATA._serialized_start=1582
  _CONNECTDATA._serialized_end=1678
  _CONNECTPROXYREQUEST._serialized_start=1681
  _CONNECTPROXYREQUEST._serialized_end=2170
  _CONNECTPROXYREPLY._serialized_start=2172
  _CONNECTPROXYREPLY._serialized_end=2289
  _CONNECTPROXYDATA._serialized_start=2291
  _CONNECTPROXYDATA._serialized_end=2387
  _CHECKCONNECTREQUEST._serialized_start=2389
  _CHECKCONNECTREQUEST._serialized_end=2410
  _CHECKCONNECTREPLY._serialized_start=2412
  _CHECKCONNECTREPLY._serialized_end=2529
  _CHECKCONNECTDATA._serialized_start=2531
  _CHECKCONNECTDATA._serialized_end=2633
  _TERMINALHEALTHCHECK._serialized_start=2636
  _TERMINALHEALTHCHECK._serialized_end=2925
  _DISCONNECTREQUEST._serialized_start=2927
  _DISCONNECTREQUEST._serialized_end=2946
  _DISCONNECTREPLY._serialized_start=2948
  _DISCONNECTREPLY._serialized_end=3061
  _DISCONNECTDATA._serialized_start=3063
  _DISCONNECTDATA._serialized_end=3138
  _CONNECTION._serialized_start=3234
  _CONNECTION._serialized_end=3836
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import mt5_term_api_market_info_pb2 as mt5__term__api__market__info__pb2


class MarketInfoStub(object):
    """The MarketInfo service provides information about the current state of the market
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SymbolsTotal = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolsTotal',
                request_serializer=mt5__term__api__market__info__pb2.SymbolsTotalRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolsTotalReply.FromString,
                )
        self.SymbolExist = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolExist',
                request_serializer=mt5__term__api__market__info__pb2.SymbolExistRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolExistReply.FromString,
                )
        self.SymbolName = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolName',
                request_serializer=mt5__term__api__market__info__pb2.SymbolNameRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolNameReply.FromString,
                )
        self.SymbolSelect = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolSelect',
                request_serializer=mt5__term__api__market__info__pb2.SymbolSelectRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolSelectReply.FromString,
                )
        self.SymbolIsSynchronized = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolIsSynchronized',
                request_serializer=mt5__term__api__market__info__pb2.SymbolIsSynchronizedRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolIsSynchronizedReply.FromString,
                )
        self.SymbolInfoDouble = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolInfoDouble',
                request_serializer=mt5__term__api__market__info__pb2.SymbolInfoDoubleRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolInfoDoubleReply.FromString,
                )
        self.SymbolInfoInteger = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolInfoInteger',
                request_serializer=mt5__term__api__market__info__pb2.SymbolInfoIntegerRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolInfoIntegerReply.FromString,
                )
        self.SymbolInfoString = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolInfoString',
                request_serializer=mt5__term__api__market__info__pb2.SymbolInfoStringRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolInfoStringReply.FromString,
                )
        self.SymbolInfoMarginRate = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolInfoMarginRate',
                request_serializer=mt5__term__api__market__info__pb2.SymbolInfoMarginRateRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolInfoMarginRateReply.FromString,
                )
        self.SymbolInfoTick = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolInfoTick',
                request_serializer=mt5__term__api__market__info__pb2.SymbolInfoTickRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolInfoTickRequestReply.FromString,
                )
        self.SymbolInfoSessionQuote = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolInfoSessionQuote',
                request_serializer=mt5__term__api__market__info__pb2.SymbolInfoSessionQuoteRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolInfoSessionQuoteReply.FromString,
                )
        self.SymbolInfoSessionTrade = channel.unary_unary(
                '/mt5_term_api.MarketInfo/SymbolInfoSessionTrade',
                request_serializer=mt5__term__api__market__info__pb2.SymbolInfoSessionTradeRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.SymbolInfoSessionTradeReply.FromString,
                )
        self.MarketBookAdd = channel.unary_unary(
                '/mt5_term_api.MarketInfo/MarketBookAdd',
                request_serializer=mt5__term__api__market__info__pb2.MarketBookAddRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.MarketBookAddReply.FromString,
                )
        self.MarketBookRelease = channel.unary_unary(
                '/mt5_term_api.MarketInfo/MarketBookRelease',
                request_serializer=mt5__term__api__market__info__pb2.MarketBookReleaseRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.MarketBookReleaseReply.FromString,
                )
        self.MarketBookGet = channel.unary_unary(
                '/mt5_term_api.MarketInfo/MarketBookGet',
                request_serializer=mt5__term__api__market__info__pb2.MarketBookGetRequest.SerializeToString,
                response_deserializer=mt5__term__api__market__info__pb2.MarketBookGetReply.FromString,
                )


class MarketInfoServicer(object):
    """The MarketInfo service provides information about the current state of the market
    """

    def SymbolsTotal(self, request, context):
        """Returns the number of available (selected in Market Watch or all) symbols
        https://www.mql5.com/en/docs/marketinformation/symbolstotal
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolExist(self, request, context):
        """Checks if a symbol with a specified name exists
        https://www.mql5.com/en/docs/marketinformation/symbolexist
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolName(self, request, context):
        """Returns the name of a symbol
        https://www.mql5.com/en/docs/marketinformation/symbolname 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolSelect(self, request, context):
        """Selects a symbol in the Market Watch window or removes a symbol from the window
        https://www.mql5.com/en/docs/marketinformation/symbolselect
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolIsSynchronized(self, request, context):
        """The function checks whether data of a selected symbol in the terminal are synchronized with data on the trade server.
        https://www.mql5.com/en/docs/marketinformation/symbolissynchronized
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolInfoDouble(self, request, context):
        """Returns the corresponding property of a specified symbol. Immediately returns the property value.
        https://www.mql5.com/en/docs/marketinformation/symbolinfodouble
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolInfoInteger(self, request, context):
        """Returns the corresponding property of a specified symbol. 
        https://www.mql5.com/en/docs/marketinformation/symbolinfointeger
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolInfoString(self, request, context):
        """Returns the corresponding property of a specified symbol. Immediately returns the property value
        https://www.mql5.com/en/docs/marketinformation/symbolinfostring  
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolInfoMarginRate(self, request, context):
        """Returns the margin rates depending on the order type and direction
        https://www.mql5.com/en/docs/marketinformation/symbolinfomarginrate
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolInfoTick(self, request, context):
        """The function returns current prices of a specified symbol in a variable of the MqlTick type
        https://www.mql5.com/en/docs/marketinformation/symbolinfotick
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolInfoSessionQuote(self, request, context):
        """Allows receiving time of beginning and end of the specified quoting sessions for a specified symbol and day of week
        https://www.mql5.com/en/docs/marketinformation/symbolinfosessionquote
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolInfoSessionTrade(self, request, context):
        """Allows receiving time of beginning and end of the specified trading sessions for a specified symbol and day of week
        https://www.mql5.com/en/docs/marketinformation/symbolinfosessiontrade
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarketBookAdd(self, request, context):
        """Provides opening of Depth of Market for a selected symbol, and subscribes for receiving notifications of the DOM changes
        https://www.mql5.com/en/docs/marketinformation/marketbookadd
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarketBookRelease(self, request, context):
        """Provides closing of Depth of Market for a selected symbol, and cancels the subscription for receiving notifications of the DOM changes
        https://www.mql5.com/en/docs/marketinformation/marketbookrelease
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarketBookGet(self, request, context):
        """Returns a structure array MqlBookInfo containing records of the Depth of Market of a specified symbol
        https://www.mql5.com/en/docs/marketinformation/marketbookget
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MarketInfoServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SymbolsTotal': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolsTotal,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolsTotalRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolsTotalReply.SerializeToString,
            ),
            'SymbolExist': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolExist,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolExistRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolExistReply.SerializeToString,
            ),
            'SymbolName': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolName,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolNameRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolNameReply.SerializeToString,
            ),
            'SymbolSelect': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolSelect,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolSelectRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolSelectReply.SerializeToString,
            ),
            'SymbolIsSynchronized': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolIsSynchronized,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolIsSynchronizedRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolIsSynchronizedReply.SerializeToString,
            ),
            'SymbolInfoDouble': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolInfoDouble,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolInfoDoubleRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolInfoDoubleReply.SerializeToString,
            ),
            'SymbolInfoInteger': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolInfoInteger,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolInfoIntegerRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolInfoIntegerReply.SerializeToString,
            ),
            'SymbolInfoString': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolInfoString,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolInfoStringRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolInfoStringReply.SerializeToString,
            ),
            'SymbolInfoMarginRate': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolInfoMarginRate,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolInfoMarginRateRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolInfoMarginRateReply.SerializeToString,
            ),
            'SymbolInfoTick': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolInfoTick,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolInfoTickRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolInfoTickRequestReply.SerializeToString,
            ),
            'SymbolInfoSessionQuote': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolInfoSessionQuote,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolInfoSessionQuoteRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolInfoSessionQuoteReply.SerializeToString,
            ),
            'SymbolInfoSessionTrade': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolInfoSessionTrade,
                    request_deserializer=mt5__term__api__market__info__pb2.SymbolInfoSessionTradeRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.SymbolInfoSessionTradeReply.SerializeToString,
            ),
            'MarketBookAdd': grpc.unary_unary_rpc_method_handler(
                    servicer.MarketBookAdd,
                    request_deserializer=mt5__term__api__market__info__pb2.MarketBookAddRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.MarketBookAddReply.SerializeToString,
            ),
            'MarketBookRelease': grpc.unary_unary_rpc_method_handler(
                    servicer.MarketBookRelease,
                    request_deserializer=mt5__term__api__market__info__pb2.MarketBookReleaseRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.MarketBookReleaseReply.SerializeToString,
            ),
            'MarketBookGet': grpc.unary_unary_rpc_method_handler(
                    servicer.MarketBookGet,
                    request_deserializer=mt5__term__api__market__info__pb2.MarketBookGetRequest.FromString,
                    response_serializer=mt5__term__api__market__info__pb2.MarketBookGetReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'mt5_term_api.MarketInfo', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MarketInfo(object):
    """The MarketInfo service provides information about the current state of the market
    """

    @staticmethod
    def SymbolsTotal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolsTotal',
            mt5__term__api__market__info__pb2.SymbolsTotalRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolsTotalReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolExist(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolExist',
            mt5__term__api__market__info__pb2.SymbolExistRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolExistReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolName',
            mt5__term__api__market__info__pb2.SymbolNameRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolNameReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolSelect(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolSelect',
            mt5__term__api__market__info__pb2.SymbolSelectRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolSelectReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolIsSynchronized(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolIsSynchronized',
            mt5__term__api__market__info__pb2.SymbolIsSynchronizedRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolIsSynchronizedReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolInfoDouble(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolInfoDouble',
            mt5__term__api__market__info__pb2.SymbolInfoDoubleRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolInfoDoubleReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolInfoInteger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolInfoInteger',
            mt5__term__api__market__info__pb2.SymbolInfoIntegerRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolInfoIntegerReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolInfoString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolInfoString',
            mt5__term__api__market__info__pb2.SymbolInfoStringRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolInfoStringReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolInfoMarginRate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolInfoMarginRate',
            mt5__term__api__market__info__pb2.SymbolInfoMarginRateRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolInfoMarginRateReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolInfoTick(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolInfoTick',
            mt5__term__api__market__info__pb2.SymbolInfoTickRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolInfoTickRequestReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolInfoSessionQuote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolInfoSessionQuote',
            mt5__term__api__market__info__pb2.SymbolInfoSessionQuoteRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolInfoSessionQuoteReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolInfoSessionTrade(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/SymbolInfoSessionTrade',
            mt5__term__api__market__info__pb2.SymbolInfoSessionTradeRequest.SerializeToString,
            mt5__term__api__market__info__pb2.SymbolInfoSessionTradeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarketBookAdd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/MarketBookAdd',
            mt5__term__api__market__info__pb2.MarketBookAddRequest.SerializeToString,
            mt5__term__api__market__info__pb2.MarketBookAddReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarketBookRelease(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/MarketBookRelease',
            mt5__term__api__market__info__pb2.MarketBookReleaseRequest.SerializeToString,
            mt5__term__api__market__info__pb2.MarketBookReleaseReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarketBookGet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.MarketInfo/MarketBookGet',
            mt5__term__api__market__info__pb2.MarketBookGetRequest.SerializeToString,
            mt5__term__api__market__info__pb2.MarketBookGetReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import mt5_term_api_account_helper_pb2 as mt5__term__api__account__helper__pb2


class AccountHelperStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AccountSummary = channel.unary_unary(
                '/mt5_term_api.AccountHelper/AccountSummary',
                request_serializer=mt5__term__api__account__helper__pb2.AccountSummaryRequest.SerializeToString,
                response_deserializer=mt5__term__api__account__helper__pb2.AccountSummaryReply.FromString,
                )
        self.OrderHistory = channel.unary_unary(
                '/mt5_term_api.AccountHelper/OrderHistory',
                request_serializer=mt5__term__api__account__helper__pb2.OrderHistoryRequest.SerializeToString,
                response_deserializer=mt5__term__api__account__helper__pb2.OrderHistoryReply.FromString,
                )
        self.OpenedOrders = channel.unary_unary(
                '/mt5_term_api.AccountHelper/OpenedOrders',
                request_serializer=mt5__term__api__account__helper__pb2.OpenedOrdersRequest.SerializeToString,
                response_deserializer=mt5__term__api__account__helper__pb2.OpenedOrdersReply.FromString,
                )
        self.OpenedOrdersTickets = channel.unary_unary(
                '/mt5_term_api.AccountHelper/OpenedOrdersTickets',
                request_serializer=mt5__term__api__account__helper__pb2.OpenedOrdersTicketsRequest.SerializeToString,
                response_deserializer=mt5__term__api__account__helper__pb2.OpenedOrdersTicketsReply.FromString,
                )
        self.SymbolParamsMany = channel.unary_unary(
                '/mt5_term_api.AccountHelper/SymbolParamsMany',
                request_serializer=mt5__term__api__account__helper__pb2.SymbolParamsManyRequest.SerializeToString,
                response_deserializer=mt5__term__api__account__helper__pb2.SymbolParamsManyReply.FromString,
                )
        self.TickValueWithSize = channel.unary_unary(
                '/mt5_term_api.AccountHelper/TickValueWithSize',
                request_serializer=mt5__term__api__account__helper__pb2.TickValueWithSizeRequest.SerializeToString,
                response_deserializer=mt5__term__api__account__helper__pb2.TickValueWithSizeReply.FromString,
                )
        self.PositionsHistory = channel.unary_unary(
                '/mt5_term_api.AccountHelper/PositionsHistory',
                request_serializer=mt5__term__api__account__helper__pb2.PositionsHistoryRequest.SerializeToString,
                response_deserializer=mt5__term__api__account__helper__pb2.PositionsHistoryReply.FromString,
                )


class AccountHelperServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AccountSummary(self, request, context):
        """Some information about account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrderHistory(self, request, context):
        """Orders History
        [DefaultValues]
        {
        "pageNumber": "0",
        "itemsPerPage": "0",
        }  
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OpenedOrders(self, request, context):
        """Pending orders and opened positions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OpenedOrdersTickets(self, request, context):
        """Just opened order tickets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SymbolParamsMany(self, request, context):
        """Full information about symbol and his group for several symbols
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TickValueWithSize(self, request, context):
        """Tick value as array
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PositionsHistory(self, request, context):
        """History positions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountHelperServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AccountSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountSummary,
                    request_deserializer=mt5__term__api__account__helper__pb2.AccountSummaryRequest.FromString,
                    response_serializer=mt5__term__api__account__helper__pb2.AccountSummaryReply.SerializeToString,
            ),
            'OrderHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.OrderHistory,
                    request_deserializer=mt5__term__api__account__helper__pb2.OrderHistoryRequest.FromString,
                    response_serializer=mt5__term__api__account__helper__pb2.OrderHistoryReply.SerializeToString,
            ),
            'OpenedOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.OpenedOrders,
                    request_deserializer=mt5__term__api__account__helper__pb2.OpenedOrdersRequest.FromString,
                    response_serializer=mt5__term__api__account__helper__pb2.OpenedOrdersReply.SerializeToString,
            ),
            'OpenedOrdersTickets': grpc.unary_unary_rpc_method_handler(
                    servicer.OpenedOrdersTickets,
                    request_deserializer=mt5__term__api__account__helper__pb2.OpenedOrdersTicketsRequest.FromString,
                    response_serializer=mt5__term__api__account__helper__pb2.OpenedOrdersTicketsReply.SerializeToString,
            ),
            'SymbolParamsMany': grpc.unary_unary_rpc_method_handler(
                    servicer.SymbolParamsMany,
                    request_deserializer=mt5__term__api__account__helper__pb2.SymbolParamsManyRequest.FromString,
                    response_serializer=mt5__term__api__account__helper__pb2.SymbolParamsManyReply.SerializeToString,
            ),
            'TickValueWithSize': grpc.unary_unary_rpc_method_handler(
                    servicer.TickValueWithSize,
                    request_deserializer=mt5__term__api__account__helper__pb2.TickValueWithSizeRequest.FromString,
                    response_serializer=mt5__term__api__account__helper__pb2.TickValueWithSizeReply.SerializeToString,
            ),
            'PositionsHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.PositionsHistory,
                    request_deserializer=mt5__term__api__account__helper__pb2.PositionsHistoryRequest.FromString,
                    response_serializer=mt5__term__api__account__helper__pb2.PositionsHistoryReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'mt5_term_api.AccountHelper', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AccountHelper(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AccountSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.AccountHelper/AccountSummary',
            mt5__term__api__account__helper__pb2.AccountSummaryRequest.SerializeToString,
            mt5__term__api__account__helper__pb2.AccountSummaryReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OrderHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.AccountHelper/OrderHistory',
            mt5__term__api__account__helper__pb2.OrderHistoryRequest.SerializeToString,
            mt5__term__api__account__helper__pb2.OrderHistoryReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OpenedOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.AccountHelper/OpenedOrders',
            mt5__term__api__account__helper__pb2.OpenedOrdersRequest.SerializeToString,
            mt5__term__api__account__helper__pb2.OpenedOrdersReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OpenedOrdersTickets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.AccountHelper/OpenedOrdersTickets',
            mt5__term__api__account__helper__pb2.OpenedOrdersTicketsRequest.SerializeToString,
            mt5__term__api__account__helper__pb2.OpenedOrdersTicketsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SymbolParamsMany(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.AccountHelper/SymbolParamsMany',
            mt5__term__api__account__helper__pb2.SymbolParamsManyRequest.SerializeToString,
            mt5__term__api__account__helper__pb2.SymbolParamsManyReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TickValueWithSize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.AccountHelper/TickValueWithSize',
            mt5__term__api__account__helper__pb2.TickValueWithSizeRequest.SerializeToString,
            mt5__term__api__account__helper__pb2.TickValueWithSizeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PositionsHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/mt5_term_api.AccountHelper/PositionsHistory',
            mt5__term__api__account__helper__pb2.PositionsHistoryRequest.SerializeToString,
            mt5__term__api__account__helper__pb2.PositionsHistoryReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
